@@ -4,12 +4,14 @@ use log::warn;
 use nohash_hasher::IntMap;
 use rustpython_parser::ast::Location;
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, Fix};
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::types::Range;
+
 use crate::codes::NoqaCode;
-use crate::fix::Fix;
 use crate::noqa;
 use crate::noqa::{extract_file_exemption, Directive, Exemption};
-use crate::registry::{Diagnostic, DiagnosticKind, Rule};
+use crate::registry::{AsRule, Rule};
 use crate::rule_redirects::get_redirect_target;
 use crate::rules::ruff::rules::{UnusedCodes, UnusedNOQA};
 use crate::settings::{flags, Settings};
@@ -21,7 +23,7 @@ pub fn check_noqa(
     noqa_line_for: &IntMap<usize, usize>,
     settings: &Settings,
     autofix: flags::Autofix,
-) {
+) -> Vec<usize> {
     let enforce_noqa = settings.rules.enabled(&Rule::UnusedNOQA);
 
     // Whether the file is exempted from all checks.
@@ -37,7 +39,7 @@ pub fn check_noqa(
     // Indices of diagnostics that were ignored by a `noqa` directive.
     let mut ignored_diagnostics = vec![];
 
-    let lines: Vec<&str> = contents.lines().collect();
+    let lines: Vec<&str> = contents.universal_newlines().collect();
     for lineno in commented_lines {
         match extract_file_exemption(lines[lineno - 1]) {
             Exemption::All => {
@@ -65,7 +67,7 @@ pub fn check_noqa(
 
     // Remove any ignored diagnostics.
     for (index, diagnostic) in diagnostics.iter().enumerate() {
-        if matches!(diagnostic.kind, DiagnosticKind::BlanketNOQA(..)) {
+        if matches!(diagnostic.kind.rule(), Rule::BlanketNOQA) {
             continue;
         }
 
@@ -96,7 +98,7 @@ pub fn check_noqa(
                         ignored_diagnostics.push(index);
                         continue;
                     }
-                    (Directive::Codes(.., codes), matches) => {
+                    (Directive::Codes(.., codes, _), matches) => {
                         if noqa::includes(diagnostic.kind.rule(), codes) {
                             matches.push(diagnostic.kind.rule().noqa_code());
                             ignored_diagnostics.push(index);
@@ -123,7 +125,7 @@ pub fn check_noqa(
                     ignored_diagnostics.push(index);
                     continue;
                 }
-                (Directive::Codes(.., codes), matches) => {
+                (Directive::Codes(.., codes, _), matches) => {
                     if noqa::includes(diagnostic.kind.rule(), codes) {
                         matches.push(diagnostic.kind.rule().noqa_code());
                         ignored_diagnostics.push(index);
@@ -139,7 +141,7 @@ pub fn check_noqa(
     if enforce_noqa {
         for (row, (directive, matches)) in noqa_directives {
             match directive {
-                Directive::All(spaces, start_byte, end_byte) => {
+                Directive::All(leading_spaces, start_byte, end_byte, trailing_spaces) => {
                     if matches.is_empty() {
                         let start = lines[row][..start_byte].chars().count();
                         let end = start + lines[row][start_byte..end_byte].chars().count();
@@ -149,15 +151,27 @@ pub fn check_noqa(
                             Range::new(Location::new(row + 1, start), Location::new(row + 1, end)),
                         );
                         if autofix.into() && settings.rules.should_fix(diagnostic.kind.rule()) {
-                            diagnostic.amend(Fix::deletion(
-                                Location::new(row + 1, start - spaces),
-                                Location::new(row + 1, lines[row].chars().count()),
-                            ));
+                            if start - leading_spaces == 0 && end == lines[row].chars().count() {
+                                diagnostic.amend(Fix::deletion(
+                                    Location::new(row + 1, 0),
+                                    Location::new(row + 2, 0),
+                                ));
+                            } else if end == lines[row].chars().count() {
+                                diagnostic.amend(Fix::deletion(
+                                    Location::new(row + 1, start - leading_spaces),
+                                    Location::new(row + 1, end + trailing_spaces),
+                                ));
+                            } else {
+                                diagnostic.amend(Fix::deletion(
+                                    Location::new(row + 1, start),
+                                    Location::new(row + 1, end + trailing_spaces),
+                                ));
+                            }
                         }
                         diagnostics.push(diagnostic);
                     }
                 }
-                Directive::Codes(spaces, start_byte, end_byte, codes) => {
+                Directive::Codes(leading_spaces, start_byte, end_byte, codes, trailing_spaces) => {
                     let mut disabled_codes = vec![];
                     let mut unknown_codes = vec![];
                     let mut unmatched_codes = vec![];
@@ -217,15 +231,28 @@ pub fn check_noqa(
                         );
                         if autofix.into() && settings.rules.should_fix(diagnostic.kind.rule()) {
                             if valid_codes.is_empty() {
-                                diagnostic.amend(Fix::deletion(
-                                    Location::new(row + 1, start - spaces),
-                                    Location::new(row + 1, lines[row].chars().count()),
-                                ));
+                                if start - leading_spaces == 0 && end == lines[row].chars().count()
+                                {
+                                    diagnostic.amend(Fix::deletion(
+                                        Location::new(row + 1, 0),
+                                        Location::new(row + 2, 0),
+                                    ));
+                                } else if end == lines[row].chars().count() {
+                                    diagnostic.amend(Fix::deletion(
+                                        Location::new(row + 1, start - leading_spaces),
+                                        Location::new(row + 1, end + trailing_spaces),
+                                    ));
+                                } else {
+                                    diagnostic.amend(Fix::deletion(
+                                        Location::new(row + 1, start),
+                                        Location::new(row + 1, end + trailing_spaces),
+                                    ));
+                                }
                             } else {
                                 diagnostic.amend(Fix::replacement(
                                     format!("# noqa: {}", valid_codes.join(", ")),
                                     Location::new(row + 1, start),
-                                    Location::new(row + 1, lines[row].chars().count()),
+                                    Location::new(row + 1, end),
                                 ));
                             }
                         }
@@ -238,7 +265,5 @@ pub fn check_noqa(
     }
 
     ignored_diagnostics.sort_unstable();
-    for index in ignored_diagnostics.iter().rev() {
-        diagnostics.swap_remove(*index);
-    }
+    ignored_diagnostics
 }
