@@ -5,18 +5,16 @@
 //!
 //! [Ruff]: https://github.com/charliermarsh/ruff
 
-pub use ast::types::Range;
-use cfg_if::cfg_if;
+pub use ruff_python_ast::source_code::round_trip;
+pub use ruff_python_ast::types::Range;
 pub use rule_selector::RuleSelector;
 pub use rules::pycodestyle::rules::IOError;
-pub use violation::{AutofixKind, Availability as AutofixAvailability};
 
-mod ast;
 mod autofix;
 mod checkers;
 mod codes;
 mod cst;
-mod directives;
+pub mod directives;
 mod doc_lines;
 mod docstrings;
 pub mod fix;
@@ -27,24 +25,13 @@ pub mod linter;
 pub mod logging;
 pub mod message;
 mod noqa;
+pub mod packaging;
 pub mod registry;
 pub mod resolver;
 mod rule_redirects;
 mod rule_selector;
-mod rules;
+pub mod rules;
 pub mod settings;
-pub mod source_code;
-mod violation;
-mod visibility;
-
-cfg_if! {
-    if #[cfg(target_family = "wasm")] {
-        mod lib_wasm;
-        pub use lib_wasm::check;
-    } else {
-        pub mod packaging;
-    }
-}
 
 #[cfg(test)]
 mod test;
