@@ -1,16 +1,15 @@
 use rustpython_parser::ast::{Excepthandler, Expr, Stmt, StmtKind};
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
 use crate::rules::flake8_bandit::helpers::is_untyped_exception;
-use crate::violation::Violation;
 
-define_violation!(
-    pub struct TryExceptPass;
-);
+#[violation]
+pub struct TryExceptPass;
+
 impl Violation for TryExceptPass {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -31,9 +30,8 @@ pub fn try_except_pass(
         && body[0].node == StmtKind::Pass
         && (check_typed_exception || is_untyped_exception(type_, checker))
     {
-        checker.diagnostics.push(Diagnostic::new(
-            TryExceptPass,
-            Range::from_located(excepthandler),
-        ));
+        checker
+            .diagnostics
+            .push(Diagnostic::new(TryExceptPass, Range::from(excepthandler)));
     }
 }
