@@ -7,17 +7,17 @@
 //! by the unpacked sequence, and this change of ordering can surprise and
 //! mislead readers.
 
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Expr, ExprKind, Keyword};
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct StarArgUnpackingAfterKeywordArg;
 
-define_violation!(
-    pub struct StarArgUnpackingAfterKeywordArg;
-);
 impl Violation for StarArgUnpackingAfterKeywordArg {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -43,7 +43,7 @@ pub fn star_arg_unpacking_after_keyword_arg(
         }
         checker.diagnostics.push(Diagnostic::new(
             StarArgUnpackingAfterKeywordArg,
-            Range::from_located(arg),
+            Range::from(arg),
         ));
     }
 }
