@@ -1,35 +1,37 @@
 use log::error;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Expr, ExprKind, Keyword};
 
-use super::helpers;
-use crate::ast::types::Range;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
+use crate::registry::AsRule;
 use crate::rules::flake8_comprehensions::fixes;
-use crate::violation::AlwaysAutofixableViolation;
+
+use super::helpers;
+
+/// ## What it does
+/// Checks for unnecessary generators that can be rewritten as `set`
+/// comprehensions.
+///
+/// ## Why is this bad?
+/// It is unnecessary to use `set` around a generator expression, since
+/// there are equivalent comprehensions for these types. Using a
+/// comprehension is clearer and more idiomatic.
+///
+/// ## Examples
+/// ```python
+/// set(f(x) for x in foo)
+/// ```
+///
+/// Use instead:
+/// ```python
+/// {f(x) for x in foo}
+/// ```
+#[violation]
+pub struct UnnecessaryGeneratorSet;
 
-define_violation!(
-    /// ## What it does
-    /// Checks for unnecessary generators that can be rewritten as `set`
-    /// comprehensions.
-    ///
-    /// ## Why is this bad?
-    /// It is unnecessary to use `set` around a generator expression, since
-    /// there are equivalent comprehensions for these types. Using a
-    /// comprehension is clearer and more idiomatic.
-    ///
-    /// ## Examples
-    /// ```python
-    /// set(f(x) for x in foo)
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// {f(x) for x in foo}
-    /// ```
-    pub struct UnnecessaryGeneratorSet;
-);
 impl AlwaysAutofixableViolation for UnnecessaryGeneratorSet {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -53,11 +55,11 @@ pub fn unnecessary_generator_set(
     let Some(argument) = helpers::exactly_one_argument_with_matching_function("set", func, args, keywords) else {
         return;
     };
-    if !checker.is_builtin("set") {
+    if !checker.ctx.is_builtin("set") {
         return;
     }
     if let ExprKind::GeneratorExp { .. } = argument {
-        let mut diagnostic = Diagnostic::new(UnnecessaryGeneratorSet, Range::from_located(expr));
+        let mut diagnostic = Diagnostic::new(UnnecessaryGeneratorSet, Range::from(expr));
         if checker.patch(diagnostic.kind.rule()) {
             match fixes::fix_unnecessary_generator_set(
                 checker.locator,
