@@ -1,19 +1,21 @@
 use log::error;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Expr, ExprKind, Keyword};
 
-use super::helpers;
-use crate::ast::types::Range;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
+use crate::registry::AsRule;
 use crate::rules::flake8_comprehensions::fixes;
-use crate::violation::AlwaysAutofixableViolation;
+
+use super::helpers;
+
+#[violation]
+pub struct UnnecessaryLiteralDict {
+    pub obj_type: String,
+}
 
-define_violation!(
-    pub struct UnnecessaryLiteralDict {
-        pub obj_type: String,
-    }
-);
 impl AlwaysAutofixableViolation for UnnecessaryLiteralDict {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -37,7 +39,7 @@ pub fn unnecessary_literal_dict(
     let Some(argument) = helpers::exactly_one_argument_with_matching_function("dict", func, args, keywords) else {
         return;
     };
-    if !checker.is_builtin("dict") {
+    if !checker.ctx.is_builtin("dict") {
         return;
     }
     let (kind, elts) = match argument {
@@ -56,7 +58,7 @@ pub fn unnecessary_literal_dict(
         UnnecessaryLiteralDict {
             obj_type: kind.to_string(),
         },
-        Range::from_located(expr),
+        Range::from(expr),
     );
     if checker.patch(diagnostic.kind.rule()) {
         match fixes::fix_unnecessary_literal_dict(checker.locator, checker.stylist, expr) {
