@@ -1,19 +1,21 @@
 use log::error;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Expr, ExprKind};
 
-use super::helpers;
-use crate::ast::types::Range;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
+use crate::registry::AsRule;
 use crate::rules::flake8_comprehensions::fixes;
-use crate::violation::AlwaysAutofixableViolation;
+
+use super::helpers;
+
+#[violation]
+pub struct UnnecessaryLiteralWithinListCall {
+    pub literal: String,
+}
 
-define_violation!(
-    pub struct UnnecessaryLiteralWithinListCall {
-        pub literal: String,
-    }
-);
 impl AlwaysAutofixableViolation for UnnecessaryLiteralWithinListCall {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -52,7 +54,7 @@ pub fn unnecessary_literal_within_list_call(
     let Some(argument) = helpers::first_argument_with_matching_function("list", func, args) else {
         return;
     };
-    if !checker.is_builtin("list") {
+    if !checker.ctx.is_builtin("list") {
         return;
     }
     let argument_kind = match argument {
@@ -64,7 +66,7 @@ pub fn unnecessary_literal_within_list_call(
         UnnecessaryLiteralWithinListCall {
             literal: argument_kind.to_string(),
         },
-        Range::from_located(expr),
+        Range::from(expr),
     );
     if checker.patch(diagnostic.kind.rule()) {
         match fixes::fix_unnecessary_literal_within_list_call(
