@@ -1,48 +1,49 @@
 use rustpython_parser::ast::Constant::Bool;
 use rustpython_parser::ast::{Expr, ExprKind, Stmt, StmtKind};
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
 
 use super::helpers;
 
-define_violation!(
-    /// ## What it does
-    /// Checks nullable string-based fields (like `CharField` and `TextField`)
-    /// in Django models.
-    ///
-    /// ## Why is this bad?
-    /// If a string-based field is nullable, then your model will have two possible
-    /// representations for "no data": `None` and the empty string. This can lead to
-    /// confusion, as clients of the API have to check for both `None` and the
-    /// empty string when trying to determine if the field has data.
-    ///
-    /// The Django convention is to use the empty string in lieu of `None` for
-    /// string-based fields.
-    ///
-    /// ## Example
-    /// ```python
-    /// from django.db import models
-    ///
-    /// class MyModel(models.Model):
-    ///    field = models.CharField(max_length=255, null=True)
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// from django.db import models
-    ///
-    /// class MyModel(models.Model):
-    ///     field = models.CharField(max_length=255, default="")
-    /// ```
-    pub struct NullableModelStringField {
-        pub field_name: String,
-    }
-);
+/// ## What it does
+/// Checks nullable string-based fields (like `CharField` and `TextField`)
+/// in Django models.
+///
+/// ## Why is this bad?
+/// If a string-based field is nullable, then your model will have two possible
+/// representations for "no data": `None` and the empty string. This can lead to
+/// confusion, as clients of the API have to check for both `None` and the
+/// empty string when trying to determine if the field has data.
+///
+/// The Django convention is to use the empty string in lieu of `None` for
+/// string-based fields.
+///
+/// ## Example
+/// ```python
+/// from django.db import models
+///
+///
+/// class MyModel(models.Model):
+///     field = models.CharField(max_length=255, null=True)
+/// ```
+///
+/// Use instead:
+/// ```python
+/// from django.db import models
+///
+///
+/// class MyModel(models.Model):
+///     field = models.CharField(max_length=255, default="")
+/// ```
+#[violation]
+pub struct NullableModelStringField {
+    pub field_name: String,
+}
+
 impl Violation for NullableModelStringField {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -72,7 +73,7 @@ pub fn nullable_model_string_field(checker: &Checker, body: &[Stmt]) -> Vec<Diag
                 NullableModelStringField {
                     field_name: field_name.to_string(),
                 },
-                Range::from_located(value),
+                Range::from(value),
             ));
         }
     }
