@@ -1,16 +1,16 @@
 use rustpython_parser::ast::{Expr, Keyword};
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::is_const_none;
+use ruff_python_ast::types::Range;
 
-use crate::ast::helpers::is_const_none;
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+use crate::registry::AsRule;
+
+#[violation]
+pub struct PrintFound;
 
-define_violation!(
-    pub struct PrintFound;
-);
 impl Violation for PrintFound {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -18,9 +18,9 @@ impl Violation for PrintFound {
     }
 }
 
-define_violation!(
-    pub struct PPrintFound;
-);
+#[violation]
+pub struct PPrintFound;
+
 impl Violation for PPrintFound {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -31,7 +31,7 @@ impl Violation for PPrintFound {
 /// T201, T203
 pub fn print_call(checker: &mut Checker, func: &Expr, keywords: &[Keyword]) {
     let diagnostic = {
-        let call_path = checker.resolve_call_path(func);
+        let call_path = checker.ctx.resolve_call_path(func);
         if call_path
             .as_ref()
             .map_or(false, |call_path| *call_path.as_slice() == ["", "print"])
@@ -43,22 +43,22 @@ pub fn print_call(checker: &mut Checker, func: &Expr, keywords: &[Keyword]) {
                 .find(|keyword| keyword.node.arg.as_ref().map_or(false, |arg| arg == "file"))
             {
                 if !is_const_none(&keyword.node.value) {
-                    if checker
-                        .resolve_call_path(&keyword.node.value)
-                        .map_or(true, |call_path| {
+                    if checker.ctx.resolve_call_path(&keyword.node.value).map_or(
+                        true,
+                        |call_path| {
                             call_path.as_slice() != ["sys", "stdout"]
                                 && call_path.as_slice() != ["sys", "stderr"]
-                        })
-                    {
+                        },
+                    ) {
                         return;
                     }
                 }
             }
-            Diagnostic::new(PrintFound, Range::from_located(func))
+            Diagnostic::new(PrintFound, Range::from(func))
         } else if call_path.as_ref().map_or(false, |call_path| {
             *call_path.as_slice() == ["pprint", "pprint"]
         }) {
-            Diagnostic::new(PPrintFound, Range::from_located(func))
+            Diagnostic::new(PPrintFound, Range::from(func))
         } else {
             return;
         }
