@@ -1,24 +1,24 @@
 use itertools::Itertools;
 use rustpython_parser::ast::{Constant, Expr, ExprKind, Location, Stmt, StmtKind};
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Violation};
+use ruff_diagnostics::{Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::{elif_else_range, end_of_statement};
+use ruff_python_ast::types::Range;
+use ruff_python_ast::visitor::Visitor;
+use ruff_python_ast::whitespace::indentation;
 
-use crate::ast::helpers::{elif_else_range, end_of_statement};
-use crate::ast::types::Range;
-use crate::ast::visitor::Visitor;
-use crate::ast::whitespace::indentation;
 use crate::checkers::ast::Checker;
-use crate::fix::Fix;
-use crate::registry::{Diagnostic, Rule};
-use crate::violation::{AlwaysAutofixableViolation, Violation};
+use crate::registry::{AsRule, Rule};
 
 use super::branch::Branch;
 use super::helpers::result_exists;
 use super::visitor::{ReturnVisitor, Stack};
 
-define_violation!(
-    pub struct UnnecessaryReturnNone;
-);
+#[violation]
+pub struct UnnecessaryReturnNone;
+
 impl AlwaysAutofixableViolation for UnnecessaryReturnNone {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -32,9 +32,9 @@ impl AlwaysAutofixableViolation for UnnecessaryReturnNone {
     }
 }
 
-define_violation!(
-    pub struct ImplicitReturnValue;
-);
+#[violation]
+pub struct ImplicitReturnValue;
+
 impl AlwaysAutofixableViolation for ImplicitReturnValue {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -46,9 +46,9 @@ impl AlwaysAutofixableViolation for ImplicitReturnValue {
     }
 }
 
-define_violation!(
-    pub struct ImplicitReturn;
-);
+#[violation]
+pub struct ImplicitReturn;
+
 impl AlwaysAutofixableViolation for ImplicitReturn {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -60,9 +60,9 @@ impl AlwaysAutofixableViolation for ImplicitReturn {
     }
 }
 
-define_violation!(
-    pub struct UnnecessaryAssign;
-);
+#[violation]
+pub struct UnnecessaryAssign;
+
 impl Violation for UnnecessaryAssign {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -70,11 +70,11 @@ impl Violation for UnnecessaryAssign {
     }
 }
 
-define_violation!(
-    pub struct SuperfluousElseReturn {
-        pub branch: Branch,
-    }
-);
+#[violation]
+pub struct SuperfluousElseReturn {
+    pub branch: Branch,
+}
+
 impl Violation for SuperfluousElseReturn {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -83,11 +83,11 @@ impl Violation for SuperfluousElseReturn {
     }
 }
 
-define_violation!(
-    pub struct SuperfluousElseRaise {
-        pub branch: Branch,
-    }
-);
+#[violation]
+pub struct SuperfluousElseRaise {
+    pub branch: Branch,
+}
+
 impl Violation for SuperfluousElseRaise {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -96,11 +96,11 @@ impl Violation for SuperfluousElseRaise {
     }
 }
 
-define_violation!(
-    pub struct SuperfluousElseContinue {
-        pub branch: Branch,
-    }
-);
+#[violation]
+pub struct SuperfluousElseContinue {
+    pub branch: Branch,
+}
+
 impl Violation for SuperfluousElseContinue {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -109,11 +109,11 @@ impl Violation for SuperfluousElseContinue {
     }
 }
 
-define_violation!(
-    pub struct SuperfluousElseBreak {
-        pub branch: Branch,
-    }
-);
+#[violation]
+pub struct SuperfluousElseBreak {
+    pub branch: Branch,
+}
+
 impl Violation for SuperfluousElseBreak {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -137,7 +137,7 @@ fn unnecessary_return_none(checker: &mut Checker, stack: &Stack) {
         ) {
             continue;
         }
-        let mut diagnostic = Diagnostic::new(UnnecessaryReturnNone, Range::from_located(stmt));
+        let mut diagnostic = Diagnostic::new(UnnecessaryReturnNone, Range::from(*stmt));
         if checker.patch(diagnostic.kind.rule()) {
             diagnostic.amend(Fix::replacement(
                 "return".to_string(),
@@ -155,7 +155,7 @@ fn implicit_return_value(checker: &mut Checker, stack: &Stack) {
         if expr.is_some() {
             continue;
         }
-        let mut diagnostic = Diagnostic::new(ImplicitReturnValue, Range::from_located(stmt));
+        let mut diagnostic = Diagnostic::new(ImplicitReturnValue, Range::from(*stmt));
         if checker.patch(diagnostic.kind.rule()) {
             diagnostic.amend(Fix::replacement(
                 "return None".to_string(),
@@ -192,11 +192,14 @@ const NORETURN_FUNCS: &[&[&str]] = &[
 
 /// Return `true` if the `func` is a known function that never returns.
 fn is_noreturn_func(checker: &Checker, func: &Expr) -> bool {
-    checker.resolve_call_path(func).map_or(false, |call_path| {
-        NORETURN_FUNCS
-            .iter()
-            .any(|target| call_path.as_slice() == *target)
-    })
+    checker
+        .ctx
+        .resolve_call_path(func)
+        .map_or(false, |call_path| {
+            NORETURN_FUNCS
+                .iter()
+                .any(|target| call_path.as_slice() == *target)
+        })
 }
 
 /// RET503
@@ -209,7 +212,7 @@ fn implicit_return(checker: &mut Checker, stmt: &Stmt) {
             if let Some(last_stmt) = orelse.last() {
                 implicit_return(checker, last_stmt);
             } else {
-                let mut diagnostic = Diagnostic::new(ImplicitReturn, Range::from_located(stmt));
+                let mut diagnostic = Diagnostic::new(ImplicitReturn, Range::from(stmt));
                 if checker.patch(diagnostic.kind.rule()) {
                     if let Some(indent) = indentation(checker.locator, stmt) {
                         let mut content = String::new();
@@ -249,7 +252,7 @@ fn implicit_return(checker: &mut Checker, stmt: &Stmt) {
             if let Some(last_stmt) = orelse.last() {
                 implicit_return(checker, last_stmt);
             } else {
-                let mut diagnostic = Diagnostic::new(ImplicitReturn, Range::from_located(stmt));
+                let mut diagnostic = Diagnostic::new(ImplicitReturn, Range::from(stmt));
                 if checker.patch(diagnostic.kind.rule()) {
                     if let Some(indent) = indentation(checker.locator, stmt) {
                         let mut content = String::new();
@@ -288,7 +291,7 @@ fn implicit_return(checker: &mut Checker, stmt: &Stmt) {
                     if is_noreturn_func(checker, func)
             ) => {}
         _ => {
-            let mut diagnostic = Diagnostic::new(ImplicitReturn, Range::from_located(stmt));
+            let mut diagnostic = Diagnostic::new(ImplicitReturn, Range::from(stmt));
             if checker.patch(diagnostic.kind.rule()) {
                 if let Some(indent) = indentation(checker.locator, stmt) {
                     let mut content = String::new();
@@ -306,6 +309,15 @@ fn implicit_return(checker: &mut Checker, stmt: &Stmt) {
     }
 }
 
+fn has_multiple_assigns(id: &str, stack: &Stack) -> bool {
+    if let Some(assigns) = stack.assigns.get(&id) {
+        if assigns.len() > 1 {
+            return true;
+        }
+    }
+    false
+}
+
 fn has_refs_before_next_assign(id: &str, return_location: Location, stack: &Stack) -> bool {
     let mut before_assign: &Location = &Location::default();
     let mut after_assign: Option<&Location> = None;
@@ -380,14 +392,14 @@ fn unnecessary_assign(checker: &mut Checker, stack: &Stack, expr: &Expr) {
         }
 
         if !stack.refs.contains_key(id.as_str()) {
-            checker.diagnostics.push(Diagnostic::new(
-                UnnecessaryAssign,
-                Range::from_located(expr),
-            ));
+            checker
+                .diagnostics
+                .push(Diagnostic::new(UnnecessaryAssign, Range::from(expr)));
             return;
         }
 
-        if has_refs_before_next_assign(id, expr.location, stack)
+        if has_multiple_assigns(id, stack)
+            || has_refs_before_next_assign(id, expr.location, stack)
             || has_refs_or_assigns_within_try_or_loop(id, stack)
         {
             return;
@@ -397,10 +409,9 @@ fn unnecessary_assign(checker: &mut Checker, stack: &Stack, expr: &Expr) {
             return;
         }
 
-        checker.diagnostics.push(Diagnostic::new(
-            UnnecessaryAssign,
-            Range::from_located(expr),
-        ));
+        checker
+            .diagnostics
+            .push(Diagnostic::new(UnnecessaryAssign, Range::from(expr)));
     }
 }
 
@@ -413,7 +424,7 @@ fn superfluous_else_node(checker: &mut Checker, stmt: &Stmt, branch: Branch) ->
         if matches!(child.node, StmtKind::Return { .. }) {
             let diagnostic = Diagnostic::new(
                 SuperfluousElseReturn { branch },
-                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from_located(stmt)),
+                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from(stmt)),
             );
             if checker.settings.rules.enabled(diagnostic.kind.rule()) {
                 checker.diagnostics.push(diagnostic);
@@ -423,7 +434,7 @@ fn superfluous_else_node(checker: &mut Checker, stmt: &Stmt, branch: Branch) ->
         if matches!(child.node, StmtKind::Break) {
             let diagnostic = Diagnostic::new(
                 SuperfluousElseBreak { branch },
-                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from_located(stmt)),
+                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from(stmt)),
             );
             if checker.settings.rules.enabled(diagnostic.kind.rule()) {
                 checker.diagnostics.push(diagnostic);
@@ -433,7 +444,7 @@ fn superfluous_else_node(checker: &mut Checker, stmt: &Stmt, branch: Branch) ->
         if matches!(child.node, StmtKind::Raise { .. }) {
             let diagnostic = Diagnostic::new(
                 SuperfluousElseRaise { branch },
-                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from_located(stmt)),
+                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from(stmt)),
             );
             if checker.settings.rules.enabled(diagnostic.kind.rule()) {
                 checker.diagnostics.push(diagnostic);
@@ -443,7 +454,7 @@ fn superfluous_else_node(checker: &mut Checker, stmt: &Stmt, branch: Branch) ->
         if matches!(child.node, StmtKind::Continue) {
             let diagnostic = Diagnostic::new(
                 SuperfluousElseContinue { branch },
-                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from_located(stmt)),
+                elif_else_range(stmt, checker.locator).unwrap_or_else(|| Range::from(stmt)),
             );
             if checker.settings.rules.enabled(diagnostic.kind.rule()) {
                 checker.diagnostics.push(diagnostic);
