@@ -1,58 +1,57 @@
 use rustpython_parser::ast::{Expr, ExprKind};
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::collect_call_path;
+use ruff_python_ast::types::{Range, ScopeKind};
 
-use crate::ast::helpers::collect_call_path;
-use crate::ast::types::{Range, ScopeKind};
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
 
-define_violation!(
-    /// ## What it does
-    /// Checks for accesses on "private" class members.
-    ///
-    /// ## Why is this bad?
-    /// In Python, the convention is such that class members that are prefixed
-    /// with a single underscore, or prefixed but not suffixed with a double
-    /// underscore, are considered private and intended for internal use.
-    ///
-    /// Using such "private" members is considered a misuse of the class, as
-    /// there are no guarantees that the member will be present in future
-    /// versions, that it will have the same type, or that it will have the same
-    /// behavior. Instead, use the class's public interface.
-    ///
-    /// ## Options
-    /// - `flake8-self.ignore-names`
-    ///
-    /// ## Example
-    /// ```python
-    /// class Class:
-    ///     def __init__(self):
-    ///         self._private_member = "..."
-    ///
-    ///
-    /// var = Class()
-    /// print(var._private_member)
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// class Class:
-    ///     def __init__(self):
-    ///         self.public_member = "..."
-    ///
-    ///
-    /// var = Class()
-    /// print(var.public_member)
-    /// ```
-    ///
-    /// ## References
-    /// - [_What is the meaning of single or double underscores before an object name?_](https://stackoverflow.com/questions/1301346/what-is-the-meaning-of-single-and-double-underscore-before-an-object-name)
-    pub struct PrivateMemberAccess {
-        pub access: String,
-    }
-);
+/// ## What it does
+/// Checks for accesses on "private" class members.
+///
+/// ## Why is this bad?
+/// In Python, the convention is such that class members that are prefixed
+/// with a single underscore, or prefixed but not suffixed with a double
+/// underscore, are considered private and intended for internal use.
+///
+/// Using such "private" members is considered a misuse of the class, as
+/// there are no guarantees that the member will be present in future
+/// versions, that it will have the same type, or that it will have the same
+/// behavior. Instead, use the class's public interface.
+///
+/// ## Options
+/// - `flake8-self.ignore-names`
+///
+/// ## Example
+/// ```python
+/// class Class:
+///     def __init__(self):
+///         self._private_member = "..."
+///
+///
+/// var = Class()
+/// print(var._private_member)
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Class:
+///     def __init__(self):
+///         self.public_member = "..."
+///
+///
+/// var = Class()
+/// print(var.public_member)
+/// ```
+///
+/// ## References
+/// - [_What is the meaning of single or double underscores before an object name?_](https://stackoverflow.com/questions/1301346/what-is-the-meaning-of-single-and-double-underscore-before-an-object-name)
+#[violation]
+pub struct PrivateMemberAccess {
+    pub access: String,
+}
+
 impl Violation for PrivateMemberAccess {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -89,6 +88,7 @@ pub fn private_member_access(checker: &mut Checker, expr: &Expr) {
 
                 // Ignore accesses on class members from _within_ the class.
                 if checker
+                    .ctx
                     .scopes
                     .iter()
                     .rev()
@@ -99,6 +99,7 @@ pub fn private_member_access(checker: &mut Checker, expr: &Expr) {
                     .map_or(false, |class_def| {
                         if call_path.as_slice() == [class_def.name] {
                             checker
+                                .ctx
                                 .find_binding(class_def.name)
                                 .map_or(false, |binding| {
                                     // TODO(charlie): Could the name ever be bound to a _different_
@@ -118,7 +119,7 @@ pub fn private_member_access(checker: &mut Checker, expr: &Expr) {
                 PrivateMemberAccess {
                     access: attr.to_string(),
                 },
-                Range::from_located(expr),
+                Range::from(expr),
             ));
         }
     }
