@@ -1,14 +1,14 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Expr, ExprKind, StmtKind};
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct OpenFileWithContextHandler;
 
-define_violation!(
-    pub struct OpenFileWithContextHandler;
-);
 impl Violation for OpenFileWithContextHandler {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -19,7 +19,7 @@ impl Violation for OpenFileWithContextHandler {
 /// Return `true` if the current expression is nested in an `await
 /// exit_stack.enter_async_context` call.
 fn match_async_exit_stack(checker: &Checker) -> bool {
-    let Some(expr) = checker.current_expr_grandparent() else {
+    let Some(expr) = checker.ctx.current_expr_grandparent() else {
         return false;
     };
     let ExprKind::Await { value } = &expr.node else {
@@ -34,13 +34,17 @@ fn match_async_exit_stack(checker: &Checker) -> bool {
     if attr != "enter_async_context" {
         return false;
     }
-    for parent in &checker.parents {
+    for parent in &checker.ctx.parents {
         if let StmtKind::With { items, .. } = &parent.node {
             for item in items {
                 if let ExprKind::Call { func, .. } = &item.context_expr.node {
-                    if checker.resolve_call_path(func).map_or(false, |call_path| {
-                        call_path.as_slice() == ["contextlib", "AsyncExitStack"]
-                    }) {
+                    if checker
+                        .ctx
+                        .resolve_call_path(func)
+                        .map_or(false, |call_path| {
+                            call_path.as_slice() == ["contextlib", "AsyncExitStack"]
+                        })
+                    {
                         return true;
                     }
                 }
@@ -53,7 +57,7 @@ fn match_async_exit_stack(checker: &Checker) -> bool {
 /// Return `true` if the current expression is nested in an
 /// `exit_stack.enter_context` call.
 fn match_exit_stack(checker: &Checker) -> bool {
-    let Some(expr) = checker.current_expr_parent() else {
+    let Some(expr) = checker.ctx.current_expr_parent() else {
         return false;
     };
     let ExprKind::Call { func,  .. } = &expr.node else {
@@ -65,13 +69,17 @@ fn match_exit_stack(checker: &Checker) -> bool {
     if attr != "enter_context" {
         return false;
     }
-    for parent in &checker.parents {
+    for parent in &checker.ctx.parents {
         if let StmtKind::With { items, .. } = &parent.node {
             for item in items {
                 if let ExprKind::Call { func, .. } = &item.context_expr.node {
-                    if checker.resolve_call_path(func).map_or(false, |call_path| {
-                        call_path.as_slice() == ["contextlib", "ExitStack"]
-                    }) {
+                    if checker
+                        .ctx
+                        .resolve_call_path(func)
+                        .map_or(false, |call_path| {
+                            call_path.as_slice() == ["contextlib", "ExitStack"]
+                        })
+                    {
                         return true;
                     }
                 }
@@ -84,12 +92,13 @@ fn match_exit_stack(checker: &Checker) -> bool {
 /// SIM115
 pub fn open_file_with_context_handler(checker: &mut Checker, func: &Expr) {
     if checker
+        .ctx
         .resolve_call_path(func)
         .map_or(false, |call_path| call_path.as_slice() == ["", "open"])
     {
-        if checker.is_builtin("open") {
+        if checker.ctx.is_builtin("open") {
             // Ex) `with open("foo.txt") as f: ...`
-            if matches!(checker.current_stmt().node, StmtKind::With { .. }) {
+            if matches!(checker.ctx.current_stmt().node, StmtKind::With { .. }) {
                 return;
             }
 
@@ -105,7 +114,7 @@ pub fn open_file_with_context_handler(checker: &mut Checker, func: &Expr) {
 
             checker.diagnostics.push(Diagnostic::new(
                 OpenFileWithContextHandler,
-                Range::from_located(func),
+                Range::from(func),
             ));
         }
     }
