@@ -1,46 +1,47 @@
 use std::fmt;
 
 use log::error;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser as parser;
 use rustpython_parser::ast::{Location, StmtKind, Suite};
 
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::is_docstring_stmt;
+use ruff_python_ast::source_code::{Locator, Stylist};
+use ruff_python_ast::types::Range;
+
+use crate::registry::Rule;
+use crate::settings::{flags, Settings};
+
 use super::super::helpers;
 use super::super::track::Block;
-use crate::ast::helpers::is_docstring_stmt;
-use crate::ast::types::Range;
-use crate::fix::Fix;
-use crate::registry::{Diagnostic, Rule};
-use crate::settings::{flags, Settings};
-use crate::source_code::{Locator, Stylist};
-use crate::violation::AlwaysAutofixableViolation;
 
-define_violation!(
-    /// ## What it does
-    /// Adds any required imports, as specified by the user, to the top of the
-    /// file.
-    ///
-    /// ## Why is this bad?
-    /// In some projects, certain imports are required to be present in all
-    /// files. For example, some projects assume that
-    /// `from __future__ import annotations` is enabled,
-    /// and thus require that import to be
-    /// present in all files. Omitting a "required" import (as specified by
-    /// the user) can cause errors or unexpected behavior.
-    ///
-    /// ## Example
-    /// ```python
-    /// import typing
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// from __future__ import annotations
-    ///
-    /// import typing
-    /// ```
-    pub struct MissingRequiredImport(pub String);
-);
+/// ## What it does
+/// Adds any required imports, as specified by the user, to the top of the
+/// file.
+///
+/// ## Why is this bad?
+/// In some projects, certain imports are required to be present in all
+/// files. For example, some projects assume that
+/// `from __future__ import annotations` is enabled,
+/// and thus require that import to be
+/// present in all files. Omitting a "required" import (as specified by
+/// the user) can cause errors or unexpected behavior.
+///
+/// ## Example
+/// ```python
+/// import typing
+/// ```
+///
+/// Use instead:
+/// ```python
+/// from __future__ import annotations
+///
+/// import typing
+/// ```
+#[violation]
+pub struct MissingRequiredImport(pub String);
+
 impl AlwaysAutofixableViolation for MissingRequiredImport {
     #[derive_message_formats]
     fn message(&self) -> String {
