@@ -1,20 +1,21 @@
 use strum::IntoEnumIterator;
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::str::leading_quote;
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::Docstring;
 use crate::docstrings::sections::SectionKind;
-use crate::fix::Fix;
 use crate::message::Location;
-use crate::registry::Diagnostic;
-use crate::rules::pydocstyle::helpers::{leading_quote, logical_line};
-use crate::violation::AlwaysAutofixableViolation;
+use crate::registry::AsRule;
+use crate::rules::pydocstyle::helpers::logical_line;
+
+#[violation]
+pub struct EndsInPeriod;
 
-define_violation!(
-    pub struct EndsInPeriod;
-);
 impl AlwaysAutofixableViolation for EndsInPeriod {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -31,7 +32,7 @@ pub fn ends_with_period(checker: &mut Checker, docstring: &Docstring) {
     let contents = docstring.contents;
     let body = docstring.body;
 
-    if let Some(first_line) = body.trim().lines().next() {
+    if let Some(first_line) = body.trim().universal_newlines().next() {
         let trimmed = first_line.trim();
 
         // Avoid false-positives: `:param`, etc.
@@ -55,11 +56,11 @@ pub fn ends_with_period(checker: &mut Checker, docstring: &Docstring) {
     }
 
     if let Some(index) = logical_line(body) {
-        let line = body.lines().nth(index).unwrap();
+        let line = body.universal_newlines().nth(index).unwrap();
         let trimmed = line.trim_end();
 
         if !trimmed.ends_with('.') {
-            let mut diagnostic = Diagnostic::new(EndsInPeriod, Range::from_located(docstring.expr));
+            let mut diagnostic = Diagnostic::new(EndsInPeriod, Range::from(docstring.expr));
             // Best-effort autofix: avoid adding a period after other punctuation marks.
             if checker.patch(diagnostic.kind.rule())
                 && !trimmed.ends_with(':')
