@@ -1,13 +1,14 @@
 use anyhow::{bail, Result};
 use libcst_native::{Call, Codegen, CodegenState, Dict, DictElement, Expression};
-use ruff_python::str::strip_quotes_and_prefixes;
 use rustpython_parser::ast::{Excepthandler, Expr};
 use rustpython_parser::{lexer, Mode, Tok};
 
-use crate::ast::types::Range;
+use ruff_diagnostics::Fix;
+use ruff_python_ast::source_code::{Locator, Stylist};
+use ruff_python_ast::str::raw_contents;
+use ruff_python_ast::types::Range;
+
 use crate::cst::matchers::{match_expr, match_module};
-use crate::fix::Fix;
-use crate::source_code::{Locator, Stylist};
 
 /// Generate a [`Fix`] to remove unused keys from format dict.
 pub fn remove_unused_format_arguments_from_dict(
@@ -16,7 +17,7 @@ pub fn remove_unused_format_arguments_from_dict(
     locator: &Locator,
     stylist: &Stylist,
 ) -> Result<Fix> {
-    let module_text = locator.slice(&Range::from_located(stmt));
+    let module_text = locator.slice(stmt);
     let mut tree = match_module(module_text)?;
     let mut body = match_expr(&mut tree)?;
 
@@ -37,7 +38,7 @@ pub fn remove_unused_format_arguments_from_dict(
                     DictElement::Simple {
                         key: Expression::SimpleString(name),
                         ..
-                    } if unused_arguments.contains(&strip_quotes_and_prefixes(name.value)) => None,
+                    } if unused_arguments.contains(&raw_contents(name.value)) => None,
                     e => Some(e.clone()),
                 })
                 .collect(),
@@ -67,7 +68,7 @@ pub fn remove_unused_keyword_arguments_from_format_call(
     locator: &Locator,
     stylist: &Stylist,
 ) -> Result<Fix> {
-    let module_text = locator.slice(&location);
+    let module_text = locator.slice(location);
     let mut tree = match_module(module_text)?;
     let mut body = match_expr(&mut tree)?;
 
@@ -114,7 +115,7 @@ pub fn remove_exception_handler_assignment(
     excepthandler: &Excepthandler,
     locator: &Locator,
 ) -> Result<Fix> {
-    let contents = locator.slice(&Range::from_located(excepthandler));
+    let contents = locator.slice(excepthandler);
     let mut fix_start = None;
     let mut fix_end = None;
 
