@@ -1,14 +1,14 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::Expr;
 
-use crate::ast::types::{FunctionDef, Range, ScopeKind};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::{FunctionDef, Range, ScopeKind};
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct AwaitOutsideAsync;
 
-define_violation!(
-    pub struct AwaitOutsideAsync;
-);
 impl Violation for AwaitOutsideAsync {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -19,6 +19,7 @@ impl Violation for AwaitOutsideAsync {
 /// PLE1142
 pub fn await_outside_async(checker: &mut Checker, expr: &Expr) {
     if !checker
+        .ctx
         .current_scopes()
         .find_map(|scope| {
             if let ScopeKind::Function(FunctionDef { async_, .. }) = &scope.kind {
@@ -29,9 +30,8 @@ pub fn await_outside_async(checker: &mut Checker, expr: &Expr) {
         })
         .unwrap_or(true)
     {
-        checker.diagnostics.push(Diagnostic::new(
-            AwaitOutsideAsync,
-            Range::from_located(expr),
-        ));
+        checker
+            .diagnostics
+            .push(Diagnostic::new(AwaitOutsideAsync, Range::from(expr)));
     }
 }
