@@ -3,12 +3,15 @@ pub use bad_str_strip_call::{bad_str_strip_call, BadStrStripCall};
 pub use bad_string_format_type::{bad_string_format_type, BadStringFormatType};
 pub use bidirectional_unicode::{bidirectional_unicode, BidirectionalUnicode};
 pub use collapsible_else_if::{collapsible_else_if, CollapsibleElseIf};
+pub use compare_to_empty_string::{compare_to_empty_string, CompareToEmptyString};
 pub use comparison_of_constant::{comparison_of_constant, ComparisonOfConstant};
 pub use consider_using_sys_exit::{consider_using_sys_exit, ConsiderUsingSysExit};
 pub use global_statement::{global_statement, GlobalStatement};
 pub use global_variable_not_assigned::GlobalVariableNotAssigned;
 pub use invalid_all_format::{invalid_all_format, InvalidAllFormat};
 pub use invalid_all_object::{invalid_all_object, InvalidAllObject};
+pub use invalid_envvar_default::{invalid_envvar_default, InvalidEnvvarDefault};
+pub use invalid_envvar_value::{invalid_envvar_value, InvalidEnvvarValue};
 pub use logging::{logging_call, LoggingTooFewArgs, LoggingTooManyArgs};
 pub use magic_value_comparison::{magic_value_comparison, MagicValueComparison};
 pub use merge_isinstance::{merge_isinstance, ConsiderMergingIsinstance};
@@ -36,12 +39,15 @@ mod bad_str_strip_call;
 mod bad_string_format_type;
 mod bidirectional_unicode;
 mod collapsible_else_if;
+mod compare_to_empty_string;
 mod comparison_of_constant;
 mod consider_using_sys_exit;
 mod global_statement;
 mod global_variable_not_assigned;
 mod invalid_all_format;
 mod invalid_all_object;
+mod invalid_envvar_default;
+mod invalid_envvar_value;
 mod logging;
 mod magic_value_comparison;
 mod merge_isinstance;
