@@ -1,14 +1,14 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{ExcepthandlerKind, MatchCase, Stmt, StmtKind};
 
-use crate::ast::helpers;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct UselessElseOnLoop;
 
-define_violation!(
-    pub struct UselessElseOnLoop;
-);
 impl Violation for UselessElseOnLoop {
     #[derive_message_formats]
     fn message(&self) -> String {
