@@ -2,21 +2,21 @@ use anyhow::{anyhow, bail, Result};
 use libcst_native::{Arg, Codegen, CodegenState, Expression};
 use once_cell::sync::Lazy;
 use regex::Regex;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::Expr;
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::source_code::{Locator, Stylist};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
 use crate::cst::matchers::{match_call, match_expression};
-use crate::fix::Fix;
-use crate::registry::Diagnostic;
+use crate::registry::AsRule;
 use crate::rules::pyflakes::format::FormatSummary;
-use crate::source_code::{Locator, Stylist};
-use crate::violation::AlwaysAutofixableViolation;
 
-define_violation!(
-    pub struct FormatLiterals;
-);
+#[violation]
+pub struct FormatLiterals;
+
 impl AlwaysAutofixableViolation for FormatLiterals {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -86,7 +86,7 @@ fn generate_call(
     locator: &Locator,
     stylist: &Stylist,
 ) -> Result<String> {
-    let module_text = locator.slice(&Range::from_located(expr));
+    let module_text = locator.slice(expr);
     let mut expression = match_expression(module_text)?;
     let mut call = match_call(&mut expression)?;
 
@@ -139,7 +139,7 @@ pub(crate) fn format_literals(checker: &mut Checker, summary: &FormatSummary, ex
         return;
     }
 
-    let mut diagnostic = Diagnostic::new(FormatLiterals, Range::from_located(expr));
+    let mut diagnostic = Diagnostic::new(FormatLiterals, Range::from(expr));
     if checker.patch(diagnostic.kind.rule()) {
         // Currently, the only issue we know of is in LibCST:
         // https://github.com/Instagram/LibCST/issues/846
