@@ -1,18 +1,18 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustc_hash::FxHashMap;
 use rustpython_parser::ast::{Expr, ExprContext, ExprKind, Stmt, StmtKind};
 
-use crate::ast::types::{Range, RefEquality};
-use crate::ast::visitor;
-use crate::ast::visitor::Visitor;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::{Range, RefEquality};
+use ruff_python_ast::visitor;
+use ruff_python_ast::visitor::Visitor;
+
 use crate::checkers::ast::Checker;
-use crate::fix::Fix;
-use crate::registry::Diagnostic;
-use crate::violation::AlwaysAutofixableViolation;
+use crate::registry::AsRule;
+
+#[violation]
+pub struct RewriteYieldFrom;
 
-define_violation!(
-    pub struct RewriteYieldFrom;
-);
 impl AlwaysAutofixableViolation for RewriteYieldFrom {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -172,9 +172,9 @@ pub fn rewrite_yield_from(checker: &mut Checker, stmt: &Stmt) {
                 continue;
             }
 
-            let mut diagnostic = Diagnostic::new(RewriteYieldFrom, Range::from_located(item.stmt));
+            let mut diagnostic = Diagnostic::new(RewriteYieldFrom, Range::from(item.stmt));
             if checker.patch(diagnostic.kind.rule()) {
-                let contents = checker.locator.slice(&Range::from_located(item.iter));
+                let contents = checker.locator.slice(item.iter);
                 let contents = format!("yield from {contents}");
                 diagnostic.amend(Fix::replacement(
                     contents,
