@@ -89,6 +89,20 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn ruf100_3() -> Result<()> {
+        let diagnostics = test_path(
+            Path::new("ruff/RUF100_3.py"),
+            &settings::Settings::for_rules(vec![
+                Rule::UnusedNOQA,
+                Rule::LineTooLong,
+                Rule::UndefinedName,
+            ]),
+        )?;
+        assert_yaml_snapshot!(diagnostics);
+        Ok(())
+    }
+
     #[test]
     fn flake8_noqa() -> Result<()> {
         let diagnostics = test_path(
