@@ -1,23 +1,19 @@
-mod ambiguous_unicode_character;
-mod asyncio_dangling_task;
-mod keyword_argument_before_star_argument;
-mod unpack_instead_of_concatenating_to_collection_literal;
-mod unused_noqa;
-
 pub use ambiguous_unicode_character::{
     ambiguous_unicode_character, AmbiguousUnicodeCharacterComment,
     AmbiguousUnicodeCharacterDocstring, AmbiguousUnicodeCharacterString,
 };
 pub use asyncio_dangling_task::{asyncio_dangling_task, AsyncioDanglingTask};
-pub use keyword_argument_before_star_argument::{
-    keyword_argument_before_star_argument, KeywordArgumentBeforeStarArgument,
-};
 pub use unpack_instead_of_concatenating_to_collection_literal::{
     unpack_instead_of_concatenating_to_collection_literal,
     UnpackInsteadOfConcatenatingToCollectionLiteral,
 };
 pub use unused_noqa::{UnusedCodes, UnusedNOQA};
 
+mod ambiguous_unicode_character;
+mod asyncio_dangling_task;
+mod unpack_instead_of_concatenating_to_collection_literal;
+mod unused_noqa;
+
 #[derive(Clone, Copy)]
 pub enum Context {
     String,
