@@ -1,16 +1,16 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Excepthandler, ExcepthandlerKind, ExprKind};
 
-use crate::ast::types::Range;
-use crate::ast::visitor::Visitor;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+use ruff_python_ast::visitor::Visitor;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
 use crate::rules::tryceratops::helpers::LoggerCandidateVisitor;
-use crate::violation::Violation;
+
+#[violation]
+pub struct ErrorInsteadOfException;
 
-define_violation!(
-    pub struct ErrorInsteadOfException;
-);
 impl Violation for ErrorInsteadOfException {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -30,10 +30,9 @@ pub fn error_instead_of_exception(checker: &mut Checker, handlers: &[Excepthandl
         for (expr, func) in calls {
             if let ExprKind::Attribute { attr, .. } = &func.node {
                 if attr == "error" {
-                    checker.diagnostics.push(Diagnostic::new(
-                        ErrorInsteadOfException,
-                        Range::from_located(expr),
-                    ));
+                    checker
+                        .diagnostics
+                        .push(Diagnostic::new(ErrorInsteadOfException, Range::from(expr)));
                 }
             }
         }
