@@ -1,6 +1,5 @@
-#![allow(dead_code)]
-
 use std::path::PathBuf;
+use std::str::FromStr;
 
 use clap::{command, Parser};
 use regex::Regex;
@@ -112,6 +111,7 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
+        value_parser = parse_rule_selector,
         help_heading = "Rule selection",
         hide_possible_values = true
     )]
@@ -121,6 +121,7 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
+        value_parser = parse_rule_selector,
         help_heading = "Rule selection",
         hide_possible_values = true
     )]
@@ -131,6 +132,7 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
+        value_parser = parse_rule_selector,
         help_heading = "Rule selection",
         hide_possible_values = true
     )]
@@ -140,6 +142,7 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
+        value_parser = parse_rule_selector,
         help_heading = "Rule selection",
         hide = true
     )]
@@ -170,6 +173,7 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
+        value_parser = parse_rule_selector,
         help_heading = "Rule selection",
         hide_possible_values = true
     )]
@@ -180,6 +184,7 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
+        value_parser = parse_rule_selector,
         help_heading = "Rule selection",
         hide_possible_values = true
     )]
@@ -403,6 +408,11 @@ impl CheckArgs {
     }
 }
 
+fn parse_rule_selector(env: &str) -> Result<RuleSelector, std::io::Error> {
+    RuleSelector::from_str(env)
+        .map_err(|e| std::io::Error::new(std::io::ErrorKind::InvalidInput, e))
+}
+
 fn resolve_bool_arg(yes: bool, no: bool) -> Option<bool> {
     match (yes, no) {
         (true, false) => Some(true),
