@@ -1,4 +1,4 @@
-use std::io::{self};
+use std::io;
 use std::path::PathBuf;
 use std::time::Instant;
 
@@ -10,10 +10,11 @@ use log::{debug, error};
 use rayon::prelude::*;
 
 use ruff::message::{Location, Message};
-use ruff::registry::{Diagnostic, Rule};
+use ruff::registry::Rule;
 use ruff::resolver::PyprojectDiscovery;
 use ruff::settings::flags;
 use ruff::{fix, fs, packaging, resolver, warn_user_once, IOError, Range};
+use ruff_diagnostics::Diagnostic;
 
 use crate::args::Overrides;
 use crate::cache;
@@ -26,6 +27,7 @@ pub fn run(
     pyproject_strategy: &PyprojectDiscovery,
     overrides: &Overrides,
     cache: flags::Cache,
+    noqa: flags::Noqa,
     autofix: fix::FixMode,
 ) -> Result<Diagnostics> {
     // Collect all the Python files to check.
@@ -84,7 +86,7 @@ pub fn run(
                         .and_then(|parent| package_roots.get(parent))
                         .and_then(|package| *package);
                     let settings = resolver.resolve_all(path, pyproject_strategy);
-                    lint_path(path, package, settings, cache, autofix)
+                    lint_path(path, package, settings, cache, noqa, autofix)
                         .map_err(|e| (Some(path.to_owned()), e.to_string()))
                 }
                 Err(e) => Err((
