@@ -1,19 +1,20 @@
 mod alias;
 mod arg;
 mod arguments;
-mod boolop;
+mod bool_op;
 pub mod builders;
-mod cmpop;
+mod cmp_op;
 mod comments;
 mod comprehension;
 mod excepthandler;
 mod expr;
 mod helpers;
+mod keyword;
 mod match_case;
 mod numbers;
 mod operator;
 mod pattern;
 mod stmt;
 mod strings;
-mod unaryop;
+mod unary_op;
 mod withitem;
